Functions to extract the 'depth' of an object
Details
This function does not count an empty lists (base::list()) as a
level or NULL objects.
Functions to extract the 'depth' of an object
This function does not count an empty lists (base::list()) as a
level or NULL objects.