Functions to list out all environments and objects
Value
environments(): Invisibly, acharactervector of environment names
ls_all(),objects_all(): A named list for each of the environments thebase::search()path with all the objects found in that environment
Details
environments() is basically a printing wrapper for
base::search()
ls_all() and objects_all() can be used retrieved all
objects from all environments in the base::search() path, which may print
out a large result into the console.